# Installation

### From sources

Download the latest LaVue version from https://github.com/lavue-org/lavue .

Extract sources and run

      $ python setup.py install

### Debian packages

Debian Bullseye (and Buster, Stretch) as well as Ubuntu Focal (and Impish, Hirsute, Bionic) packages can be found in the HDRI repository.

To install the debian packages, add the PGP repository key

      $ sudo su
      $ curl -s http://repos.pni-hdri.de/debian_repo.pub.gpg  | gpg --no-default-keyring --keyring gnupg-ring:/etc/apt/trusted.gpg.d/debian-hdri-repo.gpg --import
      $ chmod 644 /etc/apt/trusted.gpg.d/debian-hdri-repo.gpg

and then download the corresponding source list, e.g.

      $ cd /etc/apt/sources.list.d

and

      $ wget http://repos.pni-hdri.de/bullseye-pni-hdri.list

or

     $ wget http://repos.pni-hdri.de/buster-pni-hdri.list

or

      $ wget http://repos.pni-hdri.de/focal-pni-hdri.list

respectively.

Finally,

      $ apt-get update
      $ apt-get install python3-lavue

and for its tango controller

      $ apt-get install lavue-controller

or

      $ apt-get install lavue-controller3

for older python3 debian/ubuntu releases.

### From Pip

To install it from pip you need to install pyqt5 in advance, e.g.

    $ python3 -m venv myvenv
    $ . myvenv/bin/activate

    $ pip install pyqt5

    or

    $ pip install pyqt5==5.14

    and then

    $ pip install lavue

Moreover it is also good to install the following python packages:

    $ pip install fabio
    $ pip install pillow
    $ pip install pyFAI
    $ pip install lavuefilters
    $ pip install pytango